==> neper-1.8.0.tgz: neper-1.8.0/src/Utils/TessUtils/Import/TessImport.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<string.h>

#include"../../../Structs/structPoly.h"
#include"../../../Structs/structTess.h"
#include"../../BoardUtils/BoardUtils0.h"
#include"../../DisplayUtils/DisplayUtils0.h"
#include"../../../ut/ut.h"

#include"TessImport0.h"

extern void TIHead (FILE *);
extern void TIVer (struct TESS *, FILE *);
extern void TIVerHead (FILE *);
extern void TIVerQty (struct TESS *, FILE *);
extern void TIVerProp (struct TESS *, FILE *);
extern void TIVerParGerm (struct TESS *, int, FILE *);
extern void TIVerParEdge (struct TESS *, int, FILE *);
extern void TIVerCoo (struct TESS *, int, FILE *);
extern void TIEdge (struct TESS *, FILE *);
extern void TIEdgeVerNb (struct TESS *, int, FILE *);
extern void TIEdgeHead (FILE *);
extern void TIEdgeQty (struct TESS *, FILE *);
extern void TIEdgeProp (struct TESS *, FILE *);
extern void TIFace (struct TESS *, FILE *);
extern void TIFaceHead (FILE *);
extern void TIFaceQty (struct TESS *, FILE *);
extern void TIFaceGerm (struct TESS *, int, FILE *);
extern void TIFaceEq (struct TESS *, int, FILE *);
extern void TIFaceVerNEdgeProp (struct TESS *, int, FILE *);
extern void TIPolyHead (FILE *);
extern void TIPolyQty (struct TESS *, FILE *);
extern void TICenterCoo (struct TESS *, int, FILE *);
extern void TIPoly (struct TESS *, FILE *);
extern void TIPolyVerProp (struct TESS *, int, FILE *);
extern void TIPolyEdgeProp (struct TESS *, int, FILE *);
extern void TIPolyFaceProp (struct TESS *, int, FILE *);
extern void TIFaceProp (struct TESS *, FILE *);
extern void TIPolyProp (struct TESS *, FILE *);
extern void TIDomain (struct TESS *, FILE *);
extern void TIDomainHead (FILE *);
extern void TIFoot (FILE *);

extern int CharScanNComp (char *, FILE *);

==> neper-1.8.1.tgz: neper-1.8.1/src/Utils/TessUtils/Import/TessImport.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<string.h>

#include"../../../ut/ut.h"
#include"../../../neut/neut.h"
#include"../../../Structs/structPoly.h"
#include"../../BoardUtils/BoardUtils0.h"
#include"../../DisplayUtils/DisplayUtils0.h"

#include"TessImport0.h"

extern void TIHead (struct TESS*, FILE *);
extern void TIVer (struct TESS *, FILE *);
extern void TIVerHead (FILE *);
extern void TIVerQty (struct TESS *, FILE *);
extern void TIVerProp (struct TESS *, FILE *);
extern void TIVerParGerm (struct TESS *, int, FILE *);
extern void TIVerParEdge (struct TESS *, int, FILE *);
extern void TIVerCoo (struct TESS *, int, FILE *);
extern void TIEdge (struct TESS *, FILE *);
extern void TIEdgeVerNb (struct TESS *, int, FILE *);
extern void TIEdgeHead (FILE *);
extern void TIEdgeQty (struct TESS *, FILE *);
extern void TIEdgeProp (struct TESS *, FILE *);
extern void TIFace (struct TESS *, FILE *);
extern void TIFaceHead (FILE *);
extern void TIFaceQty (struct TESS *, FILE *);
extern void TIFaceGerm (struct TESS *, int, FILE *);
extern void TIFaceEq (struct TESS *, int, FILE *);
extern void TIFaceVerNEdgeProp (struct TESS *, int, FILE *);
extern void TIPolyHead (FILE *);
extern void TIPolyQty (struct TESS *, FILE *);
extern void TICenterCoo (struct TESS *, int, FILE *);
extern void TIPoly (struct TESS *, FILE *);
extern void TIPolyVerProp (struct TESS *, int, FILE *);
extern void TIPolyEdgeProp (struct TESS *, int, FILE *);
extern void TIPolyFaceProp (struct TESS *, int, FILE *);
extern void TIFaceProp (struct TESS *, FILE *);
extern void TIPolyProp (struct TESS *, FILE *);
extern void TIDomain (struct TESS *, FILE *);
extern void TIDomainHead (FILE *);
extern void TIFoot (FILE *);

extern int CharScanNComp (char *, FILE *);
